package com.nisum.productreader.service;

import com.nisum.productreader.model.Product;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;

@Service
public class ProductKafkaProducer {

    private static final Logger logger = LoggerFactory.getLogger(ProductKafkaProducer.class);

    private final KafkaTemplate<String, Product> kafkaTemplate;

    @Autowired
    public ProductKafkaProducer(KafkaTemplate<String, Product> kafkaTemplate) {
        this.kafkaTemplate = kafkaTemplate;
    }

    public void publishProducts(Flux<Product> products, String topic) {
        products.doOnNext(product -> {
            kafkaTemplate.send(topic, product.getProductId().toString(), product); // Send product
            logger.info("Published product to Kafka: {}", product);
        }).subscribe(); // Subscribe to initiate the Flux processing
    }
}
